@@ -1,7 +1,7 @@
 package Web::Query;
 our $AUTHORITY = 'cpan:TOKUHIROM';
 # ABSTRACT: Yet another scraping library like jQuery
-$Web::Query::VERSION = '0.36';
+$Web::Query::VERSION = '0.37';
 use strict;
 use warnings;
 use 5.008001;
@@ -12,7 +12,7 @@ use HTML::Selector::XPath 0.06 qw/selector_to_xpath/;
 use Scalar::Util qw/blessed refaddr/;
 use HTML::Entities qw/encode_entities/;
 
-use List::Util qw/ reduce uniq /;
+use List::Util 1.44 qw/ reduce uniq /;
 use Scalar::Util qw/ refaddr /;
 
 our @EXPORT = qw/wq/;
@@ -724,7 +724,7 @@ Web::Query - Yet another scraping library like jQuery
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
